// tests/scraper-with-user-data.spec.ts
import { test as base, BrowserContext } from "@playwright/test";
import { chromium } from "playwright";
import path from "path";

export const USER_DATA_DIR = path.resolve(__dirname, "../.user-data-dir");

export const test = base.extend<{
  context: BrowserContext;
  page: Awaited<ReturnType<BrowserContext["newPage"]>>;
}>({
  context: async ({}, use) => {
    const context = await chromium.launchPersistentContext(USER_DATA_DIR, {
      headless: false,
      args: [
        "--disable-session-crashed-bubble", // Don't show restore bubble
        "--disable-restore-session-state", // Don't try to restore session
        "--disable-background-networking", // Optional: cleaner launch
        "--disable-default-apps", // Optional: skip default Chrome apps
      ],
    });
    await use(context);
    await context.close();
  },
  page: async ({ context }, use) => {
    const page = context.pages()[0] ?? (await context.newPage());
    await use(page);
  },
});
